summaryrefslogtreecommitdiff
path: root/src/mongo/db/query/plan_executor.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/query/plan_executor.h')
-rw-r--r--src/mongo/db/query/plan_executor.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mongo/db/query/plan_executor.h b/src/mongo/db/query/plan_executor.h
index 50a11c0d2f8..aa5c845fe17 100644
--- a/src/mongo/db/query/plan_executor.h
+++ b/src/mongo/db/query/plan_executor.h
@@ -38,7 +38,7 @@ namespace mongo {
class BSONObj;
class Collection;
- class DiskLoc;
+ class RecordId;
class PlanStage;
class PlanExecutor;
struct PlanStageStats;
@@ -88,7 +88,7 @@ namespace mongo {
// 0. Let's say you have PlanExecutor* exec.
//
// 1. Register your PlanExecutor with ClientCursor. Registered executors are informed
// about DiskLoc deletions and namespace invalidation, as well as other important
// events. Do this by calling registerExec() on the executor. Alternatively, this can
// be done per-yield (as described below).
//
@@ -247,7 +247,7 @@ namespace mongo {
*
* If a YIELD_AUTO policy is set, then this method may yield.
*/
- ExecState getNext(BSONObj* objOut, DiskLoc* dlOut);
+ ExecState getNext(BSONObj* objOut, RecordId* dlOut);
/**
* Returns 'true' if the plan is done producing results (or writing), 'false' otherwise.
@@ -296,7 +296,7 @@ namespace mongo {
* state. As such, if the plan yields, it must be notified of relevant writes so that
* we can ensure that it doesn't crash if we try to access invalid state.
*/
- void invalidate(OperationContext* txn, const DiskLoc& dl, InvalidationType type);
+ void invalidate(OperationContext* txn, const RecordId& dl, InvalidationType type);
/**
* Helper method to aid in displaying an ExecState for debug or other recreational purposes.
@@ -88,7 +88,7 @@ namespace mongo {
//
// 1. Register your PlanExecutor with ClientCursor. Registered executors are informed
- // about DiskLoc deletions and namespace invalidation, as well as other important
+ // about RecordId deletions and namespace invalidation, as well as other important
// events. Do this by calling registerExec() on the executor. Alternatively, this can
// be done per-yield (as described below).